@@ -53,8 +53,6 @@ ProxyConn::ProxyConn()
 
 ProxyConn::~ProxyConn()
 {
-    if (m_pChunkIS)
-        HttpResourceManager::getInstance().recycle(m_pChunkIS);
 }
 
 
@@ -332,14 +330,11 @@ int ProxyConn::sendReqHeader()
     m_iReqHeaderSize = m_iTotalPending;
     m_iReqBodySize = pReq->getContentFinished();
     setInProcess(1);
-    if (LOG4CXX_NS::Level::isEnabled(LOG4CXX_NS::Level::DBG_HIGH))
-    {
-        LS_DBG_L("Proxy Request Headers:" );
-        log4cxx::Logger *pLogger = getLogger();
-        if (!pLogger)
-            pLogger = log4cxx::Logger::getDefault();
-        pLogger->lograw(m_iovec.begin(), m_iovec.len());
-    }
+    LS_DBG_L("Proxy Request Headers:" );
+    log4cxx::Logger *pLogger = getLogger();
+    if (!pLogger)
+        pLogger = log4cxx::Logger::getDefault();
+    pLogger->lograw(m_iovec.begin(), m_iovec.len());
     return 1;
 }
 
@@ -633,7 +628,7 @@ int ProxyConn::processResp()
             m_iRespBodySize = pHEC->getHttpSession()->getResp()->getContentLen();
             LS_DBG_L(this, "Response body size of proxy reply is %lld",
                      (long long)m_iRespBodySize);
-            if (m_iRespBodySize == LSI_RSP_BODY_SIZE_CHUNKED)
+            if (m_iRespBodySize == LSI_BODY_SIZE_CHUNK)
                 setupChunkIS();
             else if (!(respState & HEC_RESP_CONT_LEN))
                 m_iRespBodySize = INT_MAX;
