@@ -553,4 +553,26 @@ int GSockAddr::compare(const struct sockaddr *pAddr1,
 //
 // }
 
+int GSockAddr::setIp(struct sockaddr *result, const void *ip, int len)
+{
+    if (!result || !ip)
+        return -1;
+    void *dest = NULL;
+    if (result->sa_family == PF_INET)
+    {
+        if (len == sizeof(in_addr))
+            dest = &((sockaddr_in *)result)->sin_addr;
+    }
+    else
+    {
+        if (len == sizeof(in6_addr))
+            dest = &((sockaddr_in6 *)result)->sin6_addr;
+    }
+    if (dest)
+    {
+        memmove(dest, ip, len);
+        return 0;
+    }
+    return -1;
+}
 
