@@ -7,11 +7,14 @@
 #include "sslerror.h"
 #include <openssl/err.h>
 #include <string.h>
+#include <lsdef.h>
 
 #define MSG_MAX_LEN sizeof( m_achMsg ) - 1
 
 SslError::SslError() throw()
 {
+    m_achMsg[0] = 0;
+    m_iError = 0;
     char *p = m_achMsg;
     char *pEnd = &m_achMsg[MSG_MAX_LEN] - 1;
     const char *data;
@@ -25,7 +28,7 @@ SslError::SslError() throw()
         if (*data && (flag & ERR_TXT_STRING))
         {
             *p++ = ':';
-            strncpy(p, data, pEnd - p);
+            lstrncpy(p, data, pEnd - p);
         }
         p += strlen(p);
         ERR_get_error();
@@ -34,6 +37,7 @@ SslError::SslError() throw()
 
 SslError::SslError(int err) throw()
 {
+    m_achMsg[0] = 0;
     m_achMsg[MSG_MAX_LEN] = 0;
     m_iError = err;
     ERR_error_string_n(m_iError, m_achMsg, MSG_MAX_LEN);
@@ -48,7 +52,10 @@ SslError::SslError(const char *pErr) throw()
         memccpy(m_achMsg, pErr, 0, MSG_MAX_LEN);
     }
     else
+    {
         m_achMsg[0] = 0;
+        m_iError = 0;
+    }
 }
 
 SslError::~SslError() throw()
